@@ -4,7 +4,7 @@ use crate::lib::*;
 #[derive(Debug)]
 pub struct Error {
     code: u32,
-    message: String<U64>,
+    message: String<64>,
 }
 
 impl Error {
@@ -39,3 +39,15 @@ impl Display for Error {
         )
     }
 }
+
+#[cfg(test)]
+mod test {
+    use crate::error::Error;
+
+    #[test]
+    fn test_error() {
+        let e = Error::new(1, "hi");
+        assert_eq!(1, e.code);
+        assert_eq!("hi", e.message.as_str());
+    }
+}
